@@ -8,9 +8,10 @@ from notedata.tables import SqliteTable
 
 
 class AutoSaveDetail(SqliteTable):
-    def __init__(self, db_path=None, save_freq='d', save_key=None, save_with_clear=True, *args, **kwargs):
+    def __init__(self, db_path=None, save_freq='d', ms=False, save_key=None, save_with_clear=True, *args, **kwargs):
         if db_path is None:
             db_path = os.path.abspath(os.path.dirname(__file__)) + '/data/coin.db'
+        self.ms = ms
         self.save_key = save_key
         self.save_freq = save_freq
         self.save_with_clear = save_with_clear
@@ -31,15 +32,15 @@ class AutoSaveDetail(SqliteTable):
     def auto_save(self):
         time_unix = datetime.datetime.now()
         if self.save_freq in ('d', 'D', 'Day', 'day'):
-            if self.save_time_unix.day != time_unix.day:
+            if self.save_time_unix.day != time_unix.day and time_unix.hour > 1:
                 self._save(now=self.save_time_unix, pop=self.save_with_clear)
                 self.save_time_unix = time_unix
         elif self.save_freq in ('m', 'M', 'mon', 'Mon', 'month', 'Month'):
-            if self.save_time_unix.month != time_unix.month:
+            if self.save_time_unix.month != time_unix.month and time_unix.hour > 1:
                 self._save(now=self.save_time_unix, pop=self.save_with_clear)
                 self.save_time_unix = time_unix
         elif self.save_freq in ('m', 'M', 'mon', 'Mon', 'month', 'Month'):
-            if self.save_time_unix.year != time_unix.year:
+            if self.save_time_unix.year != time_unix.year and time_unix.hour > 1:
                 self._save(now=self.save_time_unix, pop=self.save_with_clear)
                 self.save_time_unix = time_unix
 
@@ -106,11 +107,10 @@ class AutoSaveDetail(SqliteTable):
         else:
             return this_day_start, this_day_end
 
-    @staticmethod
-    def date2unix(t, ms=True):
-        if ms:
-            return time.mktime(t) * 1000
-        return time.mktime(t)
+    def date2unix(self, t):
+        if self.ms:
+            return round(time.mktime(t) * 1000)
+        return round(time.mktime(t))
 
 
 class TradeDetail(AutoSaveDetail):
@@ -119,8 +119,9 @@ class TradeDetail(AutoSaveDetail):
             db_path = os.path.abspath(
                 os.path.dirname(__file__)) + '/data/coin.db'
 
-        super(TradeDetail, self).__init__(db_path=db_path, save_key='ts', table_name=table_name, *args, **kwargs)
-        self.columns = ['trade_id', 'ts', 'direction', 'price', 'amount']
+        super(TradeDetail, self).__init__(db_path=db_path, ms=True,
+                                          save_key='ts', table_name=table_name, *args, **kwargs)
+        self.columns = ['trade_id', 'amount', 'price', 'ts', 'direction']
 
     def create(self):
         self.execute("""
