@@ -1,5 +1,3 @@
-import time
-
 from notecoin.huobi.client import GenericClient, MarketClient
 from notecoin.huobi.dataset.core import *
 from notetool.tool.secret import read_secret
@@ -135,8 +133,12 @@ class TradeUpdate:
 
     def run(self):
         t = 0
+
         while True:
             self.insert_symbol()
+            if t % 10 == 0:
+                self._save()
+                pass
             if t % 100 == 0:
                 self.insert_data(trade=True, kline=True)
                 self.auto_save()
@@ -145,13 +147,18 @@ class TradeUpdate:
                 t += 1
                 time.sleep(60)
 
-            if t % 10 == 0:
-                self._save()
-            print(t)
+    def test(self):
+        import pandas as pd
+        condition = 'id>=1619400078439 and id<=1619452799999 limit 111'
+        sql = "select * from {} where {}".format(self.kline_1day.table_name, condition)
+        print(sql)
+        result = pd.read_sql(sql=sql, con=self.kline_1day.conn)
+        print(result.head(10))
 
 
 update = TradeUpdate()
-update.run()
+# update.run()
+update.test()
 
 # ps -elf|grep coin
 # nohup /root/anaconda3/bin/python3.8 /root/workspace/notechats/notecoin/notecoin/huobi/dataset/update.py >>/root/workspace/tmp/notecoin-run-$(date +%Y-%m-%d).log 2>&1 &
